@@ -1,4 +1,4 @@
-#!/usr/pkg/bin/perl
+#!/21Q1/bin/perl
 #############################################################################
 ##
 ## Copyright (C) 2016 The Qt Company Ltd.
@@ -79,9 +79,6 @@ normalizePath(\$out_basedir);
 our $build_basedir;
 our $basedir;
 
-# Make sure we use Windows line endings for chomp and friends on Windows.
-$INPUT_RECORD_SEPARATOR = "\r\n" if ($^O eq "msys");
-
 # will be defined based on the modules sync.profile
 our (%modules, %moduleheaders, @allmoduleheadersprivate, %classnames, %deprecatedheaders);
 our (@qpa_headers, @private_headers);
@@ -182,10 +179,10 @@ sub shouldMasterInclude {
     my ($iheader) = @_;
     return 0 if (basename($iheader) =~ /_/);
     return 0 if (basename($iheader) =~ /qconfig/);
+    local $/ = "\x0a";
     if (open(F, "<$iheader")) {
         while (<F>) {
-            chomp;
-            chop if /\r$/;
+            s/\x0d?\x0a//;
             return 0 if (/^\#pragma qt_no_master_include$/);
         }
         close(F);
@@ -212,21 +209,24 @@ sub classNames {
     $$clean = 1;
     $$requires = "";
 
+    my $suspended = 0;
     my $ihdrbase = basename($iheader);
 
     my $parsable = "";
+    local $/ = "\x0a";
     if(open(F, "<$iheader")) {
         while(<F>) {
+            s/\x0d?\x0a//;
             my $line = $_;
-            chomp $line;
-                        chop $line if ($line =~ /\r$/);
             if($line =~ /^\#/) {
                 $$clean = 0 if ($line =~ m/^#pragma qt_sync_skip_header_check/);
                 return @ret if($line =~ m/^#pragma qt_sync_stop_processing/);
                 push(@ret, $1) if($line =~ m/^#pragma qt_class\(([^)]*)\)[\r\n]*$/);
+                $suspended = 1 if ($line =~ m/^#pragma qt_sync_suspend_processing/);
+                $suspended = 0 if ($line =~ m/^#pragma qt_sync_resume_processing/);
                 $line = 0;
             }
-            if($line) {
+            if ($line && !$suspended) {
                 $line =~ s,//.*$,,; #remove c++ comments
                 $line .= ";" if($line =~ m/^Q_[A-Z_0-9]*\(.*\)[\r\n]*$/); #qt macro
                 $line .= ";" if($line =~ m/^QT_(BEGIN|END)_HEADER[\r\n]*$/); #qt macro
@@ -297,6 +297,7 @@ sub classNames {
 
         if($definition) {
             $definition =~ s=[\n\r]==g;
+            $definition =~ s/QT_DEPRECATED_X\s*\(\s*".*?"\s*\)//g;
             my @symbols;
             my $post_kw = qr/Q_DECL_FINAL|final|sealed/; # add here macros and keywords that go after the class-name of a class definition
             if($definition =~ m/^ *typedef *.*\(\*([^\)]*)\)\(.*\);$/) {
@@ -336,6 +337,7 @@ sub check_header {
         $header_skip_qt_begin_namespace_test = 1 if ($ignore_for_qt_begin_namespace_check{$header});
     }
 
+    local $/ = "\x0a";
     open(F, "<$iheader") or return;
     my $qt_begin_namespace_found = 0;
     my $qt_end_namespace_found = 0;
@@ -344,7 +346,7 @@ sub check_header {
     my $stop_processing = 0;
     my $we_mean_it = 0;
     while ($line = <F>) {
-        chomp $line;
+        $line =~ s/\x0d?\x0a//;
         my $output_line = 1;
         if ($line =~ /^ *\# *pragma (qt_no_included_check|qt_sync_stop_processing)/) {
             $stop_processing = 1;
@@ -965,9 +967,10 @@ foreach my $lib (@modules_to_sync) {
                         #push @files, "$out_basedir/include/Qt/$t" if(-e "$out_basedir/include/Qt/$t");
                         foreach my $file (@files) {
                            my $remove_file = 0;
+                           local $/ = "\x0a";
                            if(open(F, "<$file")) {
                                 while(my $line = <F>) {
-                                    chomp $line;
+                                    $line =~ s/\x0d?\x0a//;
                                     if($line =~ /^\#include \"([^\"]*)\"$/) {
                                         my $include = $1;
                                         $include = $subdir . "/" . $include unless(substr($include, 0, 1) eq "/");
@@ -1092,7 +1095,7 @@ foreach my $lib (@modules_to_sync) {
 #                                   }
                                     my $class_header = "$class ";
                                     $pri_install_gfiles .= $class_header
-                                        unless ($shadow || $pri_install_gfiles =~ $class_header);
+                                        unless ($shadow || $pri_install_gfiles =~ m/\b$class_header/);
                                     $injection .= ":$class";
                                 }
 
@@ -1111,7 +1114,7 @@ foreach my $lib (@modules_to_sync) {
                             elsif (!$shadow) {
                                 $pri_install_pfiles.= "$pri_install_iheader ";;
                             }
-                            $pri_injections .= fixPaths($iheader, $out_basedir)
+                            $pri_injections .= fixPaths($iheader, $build_basedir)
                                                .":".($no_stamp ? "^" : "").fixPaths($oheader, "$out_basedir/include/$lib")
                                                .$injection." " if ($shadow);
                         }
